@@ -1,14 +1,15 @@
 """Módulo de iteração de listas
 """
-def print_lol(the_list, level=0):
+def print_lol(the_list, ident = False, level=0):
     """Função que recebe uma lista e itera. A lista pode conter vários níveis de profundiade
     """
         
     for each_item in the_list:
         if(isinstance(each_item, list)):
-            print_lol(each_item, level+1)
+            print_lol(each_item, ident, level+1)
         else:
-            for tab_stop in range(level):
-                print("\t", end='')
+            if(ident):
+                for tab_stop in range(level):
+                    print("\t", end='')
 
             print(each_item)
